@@ -29,7 +29,7 @@ use strict;
 use JSON qw( decode_json );
 use HTTP::Request::Common;
 
-our $VERSION = '1.65'; # VERSION
+our $VERSION = '1.67'; # VERSION
 
 # Alpha Vantage recommends that API call frequency does not extend far
 # beyond ~1 call per second so that they can continue to deliver
@@ -271,6 +271,14 @@ sub alphavantage {
             next;
         }
 
+        # AlphaVantage can return an empty "Global Quote" when
+        # a symbol is not found.
+        if ( ! $quote->{'01. symbol'} ) {
+            $info{ $stock, 'success' } = 0;
+            $info{ $stock, 'errormsg' } = "Symbol $stock not found.";
+            next;
+        }
+
         # %ts holds data as
         #  {
         #     "Global Quote": {
