@@ -31,7 +31,7 @@ use HTTP::Request::Common;
 use HTML::TableExtract;
 use Encode qw(decode);
 
-our $VERSION = '1.59'; # VERSION
+our $VERSION = '1.67'; # VERSION
 
 @EXPORT_OK = qw( known_currencies fetch_live_currencies );
 
@@ -359,6 +359,7 @@ my %currencies = (
             'ANDORRA',
             'AUSTRIA',
             'BELGIUM',
+            'CROATIA',
             'CYPRUS',
             'ESTONIA',
             'EUROPEAN UNION',
@@ -472,12 +473,6 @@ my %currencies = (
         'code'    => 'HNL',
         'number'  => '340'
     },
-    'HRK' => {
-        'country' => ['CROATIA'],
-        'name'    => 'Kuna',
-        'code'    => 'HRK',
-        'number'  => '191'
-    },
     'HTG' => {
         'country' => ['HAITI'],
         'name'    => 'Gourde',
@@ -896,11 +891,11 @@ my %currencies = (
         'code'    => 'SHP',
         'number'  => '654'
     },
-    'SLL' => {
+    'SLE' => {
         'country' => ['SIERRA LEONE'],
         'name'    => 'Leone',
-        'code'    => 'SLL',
-        'number'  => '694'
+        'code'    => 'SLE',
+        'number'  => '925'
     },
     'SOS' => {
         'country' => ['SOMALIA'],
@@ -1060,6 +1055,12 @@ my %currencies = (
         'code'    => 'UZS',
         'number'  => '860'
     },
+    'VED' => {
+        'country' => ['VENEZUELA (BOLIVARIAN REPUBLIC OF)'],
+        'name'    => 'Bolivar',
+        'code'    => 'VED',
+        'number'  => '926'
+    },
     'VEF' => {
         'country' => ['VENEZUELA (BOLIVARIAN REPUBLIC OF)'],
         'name'    => 'Bolivar',
